var indexSectionsWithContent =
{
  0: "_abcdefghiklmnoprstvwz",
  1: "s",
  2: "s",
  3: "s",
  4: "_deinostw",
  5: "s",
  6: "abcdefghilmnoprstwz",
  7: "s",
  8: "abcdefgiklmnoprstvwz",
  9: "amsv"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "enums",
  6: "enumvalues",
  7: "defines",
  8: "groups",
  9: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Data Structures",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Enumerations",
  6: "Enumerator",
  7: "Macros",
  8: "Modules",
  9: "Pages"
};

